@@ -97,7 +97,6 @@ extract_cb (GtkWidget   *w,
 
 			d = _gtk_message_dialog_new (GTK_WINDOW (data->dialog),
 						     GTK_DIALOG_MODAL,
-						     _GTK_ICON_NAME_DIALOG_QUESTION,
 						     msg,
 						     NULL,
 						     _GTK_LABEL_CANCEL, GTK_RESPONSE_CANCEL,
@@ -137,7 +136,6 @@ extract_cb (GtkWidget   *w,
 
 		d = _gtk_message_dialog_new (GTK_WINDOW (window),
 					     GTK_DIALOG_DESTROY_WITH_PARENT,
-					     _GTK_ICON_NAME_DIALOG_WARNING,
 					     _("Extraction not performed"),
 					     NULL,
 					     _GTK_LABEL_CLOSE, GTK_RESPONSE_OK,
