@@ -450,6 +450,7 @@ fr_archive_init (FrArchive *self)
         self->propAddCanReplace = FALSE;
         self->propAddCanStoreFolders = FALSE;
         self->propAddCanStoreLinks = FALSE;
+        self->propAddCanFollowDirectoryLinksWithoutDereferencing = TRUE;
         self->propExtractCanAvoidOverwrite = FALSE;
         self->propExtractCanSkipOlder = FALSE;
         self->propExtractCanJunkPaths = FALSE;
@@ -457,6 +458,7 @@ fr_archive_init (FrArchive *self)
         self->propTest = FALSE;
         self->propCanExtractAll = TRUE;
         self->propCanDeleteNonEmptyFolders = TRUE;
+        self->propCanDeleteAllFiles = TRUE;
         self->propCanExtractNonEmptyFolders = TRUE;
         self->propListFromFile = FALSE;
 
@@ -848,6 +850,7 @@ fr_archive_list (FrArchive           *archive,
 		g_hash_table_remove_all (archive->files_hash);
 		_g_ptr_array_free_full (archive->files, (GFunc) file_data_free, NULL);
 		archive->files = g_ptr_array_sized_new (FILE_ARRAY_INITIAL_SIZE);
+		archive->n_regular_files = 0;
 	}
 
 	FR_ARCHIVE_GET_CLASS (archive)->list (archive, password, cancellable, callback, user_data);
